==> cmlapi-8.x-1.10.tar.gz: cmlapi/src/Service/CmlService.php <==
<?php

namespace Drupal\cmlapi\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\file\Entity\File;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class Cml Service.
 */
class CmlService {

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The cml storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $cmlStorage;

  /**
   * Creates a new CmlService manager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Manager service.
   */
  public function __construct(
      ConfigFactoryInterface $config_factory,
      EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->configFactory = $config_factory;
    $this->cmlStorage = $entity_type_manager->getStorage('cml');
  }

  /**
   * Actual.
   */
  public function actual() {
    // Has 'progress' status.
    if ($current = $this->current()) {
      return $current;
    }
    // Has 'new' status, oldest.
    if ($next = $this->next()) {
      return $next;
    }
    // [failure|success] latest.
    if ($last = $this->last()) {
      return $last;
    }
    return FALSE;
  }

  /**
   * List.
   */
  public function all() {
    $list = $this->query();
    return $list;
  }

  /**
   * Next.
   */
  public function next() {
    $next = FALSE;
    $count = 1;
    $status = ['new'];
    if (!empty($list = $this->query($count, $status))) {
      $next = array_shift($list);
    }
    return $next;
  }

  /**
   * Last.
   */
  public function last() {
    $last = FALSE;
    $count = 1;
    $status = ['failure', 'success'];
    if (!empty($list = $this->query($count, $status, 'DESC'))) {
      $last = array_shift($list);
    }
    return $last;
  }

  /**
   * Current.
   */
  public function current() {
    $config = $this->configFactory->get('cmlapi.settings');
    $current = $config->get('runing_cml');
    if (!empty($current)) {
      return $this->cmlStorage->load($current);
    }
    $current = FALSE;
    $count = 1;
    $status = ['progress'];
    if (!empty($list = $this->query($count, $status))) {
      $current = array_shift($list);
    }
    return $current;
  }

  /**
   * Query.
   */
  public function query($count = FALSE, $status = ['new', 'progress'], $sort = 'ASC') {
    $entities = [];
    $entity_type = 'cml';
    $query = $this->cmlStorage->getQuery()
      ->condition('status', 1)
      ->sort('created', $sort)
      ->condition('type', 'catalog')
      ->condition('state', $status, 'IN')
      ->condition('field_file', 'NULL', '!=');
    if ($count) {
      $query->range(0, $count);
    }
    $ids = $query->execute();
    if (!empty($ids)) {
      foreach ($this->cmlStorage->loadMultiple($ids) as $id => $entity) {
        $entities[$id] = $entity;
      }
    }
    return $entities;
  }

  /**
   * Load.
   */
  public function load($id) {
    return $this->cmlStorage->load($id);
  }

  /**
   * Files Path.
   */
  public function getFilesPath($cid, $xmlkey) {
    $files = FALSE;
    if (!$cid && $cml = $this->actual()) {
      $cid = $cml->id();
    }
    if (is_numeric($cid)) {
      $files = &drupal_static("CmlService::getFilesPath():$xmlkey:$cid");
      if (!isset($files)) {
        $cache_key = "CmlService-$xmlkey:$cid";
        if ($cache = \Drupal::cache()->get($cache_key)) {
          $files = $cache->data;
        }
        else {
          $cml = $this->load($cid);
          if (is_object($cml)) {
            $cml_xml = $cml->field_file->getValue();
            $files = [];
            $data = FALSE;
            $filekeys[$xmlkey] = TRUE;
            if (!empty($cml_xml)) {
              foreach ($cml_xml as $xml) {
                $file = File::load($xml['target_id']);
                $filename = $file->getFilename();
                if (strpos($filename, 'import') === 0) {
                  $filekey = 'import';
                }
                if (strpos($filename, 'offers') === 0) {
                  $filekey = 'offers';
                }
                if (strpos($filename, 'prices') === 0) {
                  $filekey = 'prices';
                }
                if (strpos($filename, 'rests') === 0) {
                  $filekey = 'rests';
                }
                if (isset($filekeys[$filekey]) && $filekeys[$filekey]) {
                  $files[] = $file->getFileUri();
                }
              }
            }
            \Drupal::cache()->set($cache_key, $files);
          }
        }
      }
    }
    return $files;
  }

}

==> cmlapi-8.x-1.14.tar.gz: cmlapi/src/Service/CmlService.php <==
<?php

namespace Drupal\cmlapi\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\file\Entity\File;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class Cml Service.
 */
class CmlService {

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The cml storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $cmlStorage;

  /**
   * Creates a new CmlService manager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Manager service.
   */
  public function __construct(
      ConfigFactoryInterface $config_factory,
      EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->configFactory = $config_factory;
    $this->cmlStorage = $entity_type_manager->getStorage('cml');
  }

  /**
   * Actual.
   */
  public function actual() {
    // Has 'progress' status.
    if ($current = $this->current()) {
      return $current;
    }
    // Has 'new' status, oldest.
    if ($next = $this->next()) {
      return $next;
    }
    // [failure|success] latest.
    if ($last = $this->last()) {
      return $last;
    }
    return FALSE;
  }

  /**
   * List.
   */
  public function all() {
    $list = $this->query();
    return $list;
  }

  /**
   * Next.
   */
  public function next() {
    $next = FALSE;
    $count = 1;
    $status = ['new'];
    if (!empty($list = $this->query($count, $status))) {
      $next = array_shift($list);
    }
    return $next;
  }

  /**
   * Last.
   */
  public function last() {
    $last = FALSE;
    $count = 1;
    $status = ['failure', 'success'];
    if (!empty($list = $this->query($count, $status, 'DESC'))) {
      $last = array_shift($list);
    }
    return $last;
  }

  /**
   * Current.
   */
  public function current() {
    $config = $this->configFactory->get('cmlapi.settings');
    $current = $config->get('runing_cml');
    if (!empty($current)) {
      return $this->cmlStorage->load($current);
    }
    $current = FALSE;
    $count = 1;
    $status = ['progress'];
    if (!empty($list = $this->query($count, $status))) {
      $current = array_shift($list);
    }
    return $current;
  }

  /**
   * Query.
   */
  public function query($count = FALSE, $status = ['new', 'progress'], $sort = 'ASC') {
    $entities = [];
    $entity_type = 'cml';
    $query = $this->cmlStorage->getQuery()
      ->condition('status', 1)
      ->sort('created', $sort)
      ->condition('type', 'catalog')
      ->condition('state', $status, 'IN')
      ->condition('field_file', 'NULL', '!=');
    if ($count) {
      $query->range(0, $count);
    }
    $ids = $query->execute();
    if (!empty($ids)) {
      foreach ($this->cmlStorage->loadMultiple($ids) as $id => $entity) {
        $entities[$id] = $entity;
      }
    }
    return $entities;
  }

  /**
   * Load.
   */
  public function load($id) {
    return $this->cmlStorage->load($id);
  }

  /**
   * Files Path.
   */
  public function getFilesPath(int | bool $cid, $xmlkey) : array {
    $files = [];
    if (!$cid && $cml = $this->actual()) {
      $cid = $cml->id();
    }
    if (is_numeric($cid)) {
      $files = &drupal_static("CmlService::getFilesPath():$xmlkey:$cid");
      if (!isset($files)) {
        $cache_key = "CmlService-$xmlkey:$cid";
        if ($cache = \Drupal::cache()->get($cache_key)) {
          $files = $cache->data;
        }
        else {
          $cml = $this->load($cid);
          if (is_object($cml)) {
            $cml_xml = $cml->field_file->getValue();
            $files = [];
            $data = FALSE;
            $filekeys[$xmlkey] = TRUE;
            if (!empty($cml_xml)) {
              foreach ($cml_xml as $xml) {
                $file = File::load($xml['target_id']);
                $filename = $file->getFilename();
                if (strpos($filename, 'import') === 0) {
                  $filekey = 'import';
                }
                if (strpos($filename, 'offers') === 0) {
                  $filekey = 'offers';
                }
                if (strpos($filename, 'prices') === 0) {
                  $filekey = 'prices';
                }
                if (strpos($filename, 'rests') === 0) {
                  $filekey = 'rests';
                }
                if (isset($filekeys[$filekey]) && $filekeys[$filekey]) {
                  $files[] = $file->getFileUri();
                }
              }
            }
            \Drupal::cache()->set($cache_key, $files);
          }
        }
      }
    }
    return $files;
  }

}
